.. highlight:: shell

============
Installation
============


Stable release
--------------

To install ctdproc, run this command in your terminal:

.. code-block:: console

    $ pip install ctdproc

This is the preferred method to install ctdproc, as it will always install the most recent stable release.


From sources
------------

The sources for ctdproc can be downloaded from the `Github repo`_.

You can clone the public repository:

.. code-block:: console

    $ git clone git://github.com/gunnarvoet/ctdproc

Once you have a copy of the source, you can install it using pip. First change into the package directory:

.. code-block:: console

    $ cd ctdproc

Then install either as a regular package

.. code-block:: console

    $ pip install .

or in developer mode (to immediately apply changes you make to the source code):

.. code-block:: console

    $ pip install -e .



.. _Github repo: https://github.com/gunnarvoet/ctdproc
.. _tarball: https://github.com/gunnarvoet/ctdproc/tarball/master
